---
fontfamily: dejavu
fontsize: 16pt
geometry: a4paper,margin=2cm
---

![](../../images/MicroDexed-Logo.png)

# MicroDexed User Manual

Version 1.0 (June 2020)

<div style="page-break-after: always"></div>

![](../../images/MicroDexed.png)

## What is MicroDexed?

MicroDexed (also called MD) is a software which runs on a Teensy(-3.6/4.x) microcontroller. It simulates a well know 6 operator FM synthesizer with some additions (like effects) and is controlled and mostly programmed via MIDI. The sound engine is based on [Dexed](https://github.com/asb2m10/dexed), a famous open-source VST plugin.

## Requirements

To use MD, you need suitable hardware. For example [TeensyMIDIAudo (TMA)](https://codeberg.org/dcoredump/TeensyMIDIAudio/src/branch/master/Rev-1.8) was developed directly for MD. The schematics and layouts are open-source, so you can easily build a TMA board. You can also build it on a stripe grid board or use completely different variants - it's up to you how you build the hardware. Another option (with a few extensions) is the [Teensy Guitar Audio Shield](http://blackaddr.com/products/).

Basically your MD "board" needs the following:
* I2C connector for connecting a LCD display (software is written for a 2*16 character display, but a bigger one should do also).
* 2 Encoders (for each encoder one digital input for the button and two digital inputs for the encoder directions).
* A DA converter supported by Teensy (something like a "audio shield", e.g. the Teeensy audio shield, or (the simplest way) you can use the 12bit DA output pins of the Teensy-3.6 (not possible for Teensy-4.x!)).
* "A way to get MIDI into the Teensy", like the onboard USB port (will not work for USB-MIDI-keybords, because it is not a host port!), the USB-Host port (with soldering a header) or external IO-components for DIN-MIDI.
* A small FAT32 formated SD card.
* The Arduino-IDE and TeensyDuino for compiling and uploading the program code (tested with Arduino-1.8.12 and TeensyDuino-1.52).

The complete hardware build manual for the TMA-board can be found inside the [TMA-Build-Manual](https://codeberg.org/dcoredump/TeensyMIDIAudio/src/branch/master/Rev-1.8/Build-Manual/TMA-Build-Manual.pdf). So for now we expect that you have a running hardware with installed MD software.

<div style="page-break-after: always"></div>

## Operating elements on the front

The normal controls for the user are arranged as follows:

![](images/10_OperationElements_1.jpg)

If you decide to do the arrangement differently this is no problem. You only have to remember how the encoders are assigned to the function:

* Left encoder is named __VOLUME__
* Right encoder is named __PRESET__

### Permament encoder functions

The __VOLUME__ encoder always has the following functions - no matter where you are in the menus:
* __Turn left/right__: Change the volume (MIDI-CC 7). The volume-change-screen appears when turing and disapears after a short time and you get back, where you left off.
* __Long-Press__: A MIDI panic is triggered and all voices are muted.
* __Short-Press__: Back (from the selected menu-item or up to the parrent menu)
  
The __PRESET__ encoder has only two different permanent function:
* __Long-Press__ inside menu: This takes you to the sound/bank selection.
* __Long-Press__ inside voice/bank selection: Changing between voice and bank selection.

<div style="page-break-after: always"></div>

## Quick start

On a freshly installed MD the screen should greet you with the sound/bank selection. The volume is set to 80%.

__Long-Press PRESET__: Changes between voice and bank selection:
![](images/10_SoundBank_1.jpg)

 __Turn PRESET left/right__: Change voice or bank (voices: 1-32, banks: 0-99):
![](images/10_SoundBank_2.jpg)

- [<img src="../../images/LCD_characters_green/small_1_inv.png" width="12"/>](../../images/LCD_characters_green/small_1_inv.png) indicates that you are using timbre 1.
- [<img src="../../images/LCD_characters_green/key.png" width="12"/>](../../images/LCD_characters_green/key.png) indicates that you currently use the monotimbral engine.
- [<img src="../../images/LCD_characters_green/bracket_open.png" width="12"/>](../../images/LCD_characters_green/bracket_open.png)[<img src="../../images/LCD_characters_green/bracket_close.png" width="12"/>](../../images/LCD_characters_green/bracket_close.png) are showing which parameter you currently edit with the __PRESET__ encoder.
- [<img src="../../images/LCD_characters_green/note.png" width="12"/>](../../images/LCD_characters_green/note.png) below the timbre symbol(s) indicates that there was an MIDI event (if using a Teensy -4.x different height bars (depending on velocity) are displayed per timbre).

<div style="page-break-after: always"></div>

## Using MicroDexed

The individual menu items are described below. MD knows three different states:

* Voice/Bank selection
* Adjust volume
* Menu

After switching on, you are in the voice/bank selection. To enter the menu you have to press the volume encoder. You can return to the voice/bank selection by holding down the preset encoder. If you turn the volume encoder, the volume screen appears and you can see which value is set. After a few seconds the system automatically returns to the previous screen.

To select items in the menu, the preset encoder must be turned. On the right side you will see where you are in the menu list. You can select a menu item or jump to a submenu by pressing the preset encoder.

If you want to leave a menu point or change to a higher menu, the volume encoder must be operated.

---
> __Hint__:
> You can translate MD with different options and accordingly some features may or may not be available. This also depends on what kind of microcontroller you use. In > this manual the standard options are used. These are:
> 
> * Microcontroller: Teensy-3.6 (240 Mhz overclocking)
> * Teensy audio card (SGTL5000 based audio chip)
> * USB-host port enabled
> * *Mono-timbral* engine
  ---

If you use the *dual-timbral* engine, in many menus a small <img src="../../images/LCD_characters_green/small_2_inv.png" width="12"/> will appear (right of the <img src="../../images/LCD_characters_green/small_1_inv.png" width="12"/>) instead of the key. To switch between the two engines and change their parameters, simply press the preset encoder.

### Sound/Bank selection

The most important screen will be the selection for the sounds. The screen displays the selected bank number (top left) and the selected voice number (below). Next to the numbers are the corresponding names. The paramater, which is shown in square brackets, can be changed by turning the preset encoder.

MD can manage 100 banks (0-99) and 32 voices per bank, if you turn the mouse over the 32 voices, the first voice of the next bank will be loaded automatically (if possible). This happens the same way if you go lower than voice number 1.

![](images/10_SoundBank_3.jpg)

To switch between voice and bank selection, the preset encoder must be pressed for a long time.

Next to the bank name is the symbol for the active engine. As described above, we use the *mono-timbral* engine for this manual, so the display next to it has a key symbol and is therefore not available. In this case we can not switch between the two instances by pressing the preset encoder.

If a MIDI note is detected, a note symbol is displayed below the corresponding instance as long as this note is active.

When the voice is changed, MD sends a voice dump in the background via MIDI SYSEX on its selected MIDI channel. This has the advantage that external devices (like a voice editor on a PC) synchronize the data directly.

To enter the menus, the volume encoder must be operated.

### Voice Menu

The Voice menu is the most comprehensive menu. Here all functions related to sound generation are stored in different menus. 

#### Audio Menu

The audio menu contains all functions that can lead to audible changes in any form.

##### Voice Level

![](images/10_VoiceLevel_1.jpg)

By changing (and later saving) this value you can compensate for differences in volume between different sounds. The value ranges from 0 to 127. Normal is 100, but you can make the sound louder by increasing the value.

##### Panorama

![](images/10_Panorama_1.jpg)

The place in the stereo image can be adjusted here (MIDI-CC 10)

##### Effects

MD comes with some effects. Basically, each MD instance has its own resonant low-pass filter, (mono) Chorus and a separate (mono) delay (max. 250/500 ms). This is followed by the placement in the stereo image (see panorama) and a stereo reverb. A complete picture of the generation of the audio signal is stored in the [Repository](https://codeberg.org/dcoredump/MicroDexed/src/branch/master/doc/MicroDexed-Audio-FlowChart.png).

---
> __Note on effects menu:__
> It is possible to deactivate the effects at compile time. If this was done, then no effects menu is available!
---

###### (Mono-)Chorus

A simple chorus created on the mix of the original signal and a pitch-modulated original signal. The effect is only audible when frequncy, depth and level are all somehow greater than 0.

Parameter:
* Frequency (0-10 Hz)
* Waveform (Triangle/Sine)
* Depth (0-100)
* Level (0-100)

###### (Mono-)Delay

The delay has a feedback loop and can be mixed into the original signal by means of level. Therefore time and level must be greater than 0.

Parameter:
* Time: (0-500ms for *mono-timbral* or 0-250 for *dual-timbral* (on Teensy-3.6))
* Feedback (0-100)
* Level (0-100)
  
> Dedicated MIDI controller numbers:
> * Time: MIDI-CC 105
> * Feedback: MIDI-CC 106
> * Level: MIDI-CC 107

###### Filter

The filter is a resonant 4-pole low-pass filter.

Parameter:
* Cutoff (0-100)
* Resonance (0-100)
  
> Dedicated MIDI controller numbers:
> * Cutoff: MIDI-CC 104
> * Resonance: MIDI-CC 103
  
###### (Stereo) Reverb (Master effect)

The reverb is a port of the freeverb. With the *mono-timbral* engine the parameter *Reverb Send* seems to be superfluous and can be set to 100. But if you use the *dual-timbral* version, you can set the amount of reverb send for each of the two sound generators separately. The reverb can only be heard when the roomzize and level, as well as *Reverb Send* are greater than 0.

Parameter:
* Roomsize (0-100)
* Damping (0-100)
* Level (0-100)
* Reverb Send (0-100)

> Dedicated MIDI controller numbers:
> * Level: MIDI-CC 91

###### EQ (Master effect)

The EQ is only active when using a Teensy audio shield (or SGTL5000 chip). It serves as a simple adjustment of the sound image.

Parameter:
* Bass (0-100)
* Treble (0-100)

##### Controller

The controller section is responsible for the settings of the different MIDI controllers.

###### Pitchbend

The pitch of the note can be raised or lowered using the Pitch Bend control (Usually a dedicated wheel or joysitck on a master keyboard). The range can be set up to 1octave on both directions (up/down). *Range* setting defines the highest possible variation: from one semitone to a full octave.
*Steps* define if the control is continuous (step = 0) or by discrete values (steps) of 1, 2 ... 12 semitones.

Parameter:
* Range (0-12)
* Step (0-12)

###### Other controllers (Modulation-Wheel/Aftertouch/Foot-Contoller/Breath-Controller)

The other MIDI controllers all have the same modification possibilities. The allocation of modulation can affect different destinations: PITCH (pitch envelope), AMP (loudness envelope), EG (see note below). It is possible to specify targets or any combination of targets but to be able to hear an effect, the voice must be configured accordingly.

Parameter:
* Range (0-99)
* Assign (PITCH/AMP/EG or any combination)
* Mode (LINEAR/REVERSE LINEAR/DIRECT)

> Dedicated MIDI controller numbers:
> * Modulation wheel: MIDI-CC 1
> * Foot contoller: MIDI-CC 4
> * Breath controller: MIDI-CC 2

---
> __Note on target EG:__
> 
> When a controller is routed to EG (aka EG Bias), the *Range* value will define how much the controller will affect each operators output level (depending on a parameter which is internal to the sound engine’s preset, this will have a different effect, and on many cases, no effect at all).
>
> On MD, this internal parameter is called AMD (for *A*mplitude *M*odulation *D*epth) and the controller routed to EG will only have an effect on the operators when their individual *AMD* is set to a value greater than 0.
>
> If those operators are carriers, the controller routed to EG will control the overall volume of the sound.
>
> If those operators are modulators, the controller routed to EG will affect the modulation indexes, which have an effect on the harmonic content of the sound (the higher the modulators level, the richer the harmonics, leading to a brighter sound).
>
> If carriers and modulators have an *AMD* setting with a value greater than 0, then the controller routed to EG will affect, at the same time, volume and brightness of the sound.
>
> If, inside the voice-preset, *AMD* is set to 0 for all operators, then the controller will have no effect.
>
> ![](images/10_EG-BIAS_1.png)
>
>> Note on changing *AMD*: You can easily change all voice parameters by using an external MIDI-SYSEX editor (see Appendix).
---
##### MIDI

In this menu everything concerning MIDI control is set.

###### MIDI Channel

This influences on which midi channel MD reacts. A channel between 1 and 16 can be selected. Alternatively OMNI can be selected if data should be received on each MIDI channel.

###### Lowest/Highest note

You can also restrict the range to which NOten MD should react. This allows split and/or dual configurations with the *dual-timbral* engine or mehewren MD devices.

###### Send voice

The currently configured voice can be sent via MIDI SYSEX, for example to edit it in an external editor or use it on another MD.

#### Setup

The setup menu contains all other parameters that are necessary for this voice.

##### Portamento

Portamento allows the pitch to slide continuously from one note to the next one.

Parameters:
* Mode (FINGERED/FULL)
* Glissando (ON/OFF)
* Time (0-99)

> Dedicated MIDI controller numbers:
> * Portamento On-Off: MIDI-CC 65

---
> __Note on portamento:__
>
> Each musical instrument has a specific way to produce notes. Some have frets, keys, pistons and will produce discrete notes inside a scale… In european temperament, those notes are usually a chromatic scale (C, C#, D, D#, ...).
>
> On these instruments, it is uneasy, or even impossible, to produce a note between those. The pitch will then abruptly switch from one note to another, it will only vary by steps, and no intermediate pitch will be produced.
>
> On other instruments, such as violin or trombone, the pitch of the note can vary continuously, depending on the exact position of the finger on a string, or the length or the air column inside the pipe: this allows the pitch to slide continuously from one note to the next one. This is known as portamento.
> Depending on the instrumentist technique, this slide can be fast or slow. On MD, this speed is defined by the *Time* parameter. Higher values for portamento rate will produce a fast slide when lower values will result in a slower slide.
>
> In monophonic setting, the choice is given to have a constant (*Full*) portamento (all notes are concerned) or a *Fingered* portamento, which will only happen when you keep the initial key pressed, when playing a new key (legato).
>
> *Glissando* is different in that instead of producing a continuous slide between the pitches of the subsequent notes, it will play all the notes of the scale which are between those 2 notes, like a pianist gliding his finger on the keyboard, or a guitarist on his fretted guitar neck.
> A glide between C3 and E3 will play subsequently C3, C#3, D3, D#3, E3, when a portamento would result in a continuous rising of the pitch, from C3 to E3.
---

##### Polyphony

You can reduce the maximum of parallel heared voices if needed. If you recognize glitches in sound maybe reducing the polyphony by one can help to avoid these glitches.

Parameters:
* Polyphony (0-20, see note below)

---
> __Hint for polyphony:__
> Maximum polyphony depends on the used Teensy and the used clock speed at compile time. Setting the polyphony to 0 means that no sound will be produced. In *Monophonic* mode you need at least a polyphony of 2.
---

##### Transpose / Fine-tune

With these parameters you can adjust the pitch. By means of *Transpose* this is done in semitone steps (+/- 24 semitone) and by *Fine-Tune* in +/- 99 cent.

Parameters:
* Transpose (-24 - 24)
* Fine-Tune (-99 - 99)
  
##### Mono-/Polyphonic

#### Internal

##### Note Refresh

##### Velocity

##### Engine

#### Operator

#### Save voice

<div style="page-break-after: always"></div>

### Load/Save

#### Performance

#### Voice config

#### Effects

#### MIDI

##### MIDI Recv Bank

##### MIDI Snd Bank

##### MIDI Snd Voice

<div style="page-break-after: always"></div>

### System

#### Stereo/Mono

#### MIDI Soft THRU

#### EEPROM Reset

<div style="page-break-after: always"></div>

### Info

## Tips and tricks

### Editing the voices

https://www.thisdx7cartdoesnotexist.com/

https://dx7.vstforx.de/

https://synthmata.com/volca-fm/

<div style="page-break-after: always"></div>

## The menu structure
- Voice
    - Select
        - Audio
            - Voice Level
            - Panorama
            - Effects
                - Chorus
                    - Waveform
                        - Depth
                        - Level
                - Delay
                    - Time
                    - Feedback
                    - Level
                - Filter
                    - Cutoff
                    - Resonance
                - Reverb
                    - Roomsize
                    - Damping
                    - Level
                    - Reverb Send
                - EQ
                    - Bass
                    - Treble
        - Controller
            - Pitchbend
                - PB Range
                - PB Step
            - Mod Wheel
                - MW Range
                - MW Assign
                - MW Mode
            - Aftertouch
                - AT Range
                - AT Assign
                - AT Mode
            - Foot Ctrl
                - FC Range
                - FC Assign
                - FC Mode
            - Breath Ctrl
                - BC Range
                - BC Assign
                - BC Mode
        - MIDI
            - MIDI Channel
            - Lowest Note
            - Highest Note
            - Send Voice
        - Setup
            - Portamento
                - Port. Mode
                - Port. Gliss
                - Port. Time
            - Polyphony
            - Transpose
            - Fine Tune
            - Mono/Poly
        - Internal
            - Note Refresh
            - Velocity Lvl
            - Engine
        - Operator
        - Save Voice
- Load/Save
    - Performance
        - Load Perf.
        - Save Perf.
    - Voice Config
        - Load Voice Cfg
        - Save Voice Cfg
    - Effects
        - Load Effects Cfg
        - Save Effects Cfg
    - MIDI
        - MIDI Recv Bank
        - MIDI Snd Bank
        - MIDI Snd Voice
- System
    - Stereo/Mono
    - MIDI Soft THRU
    - EEPROM Reset
- Info

<div style="page-break-after: always"></div>






